@@ -1,4 +1,4 @@
-/* Copyright (c) 1996, 1997, 1998, 1999, 2000, 2001, 2002 Thorsten Kukuk
+/* Copyright (c) 1996-2003 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    The YP Server is free software; you can redistribute it and/or
@@ -29,6 +29,7 @@
 #include <time.h>
 #include "yp.h"
 #include <rpcsvc/ypclnt.h>
+#include <rpc/svc.h>
 #include <arpa/inet.h>
 #include <sys/param.h>
 #include <sys/socket.h>
@@ -45,23 +46,13 @@
 #include <ndbm.h>
 #include <fcntl.h>
 #endif
+#if defined(HAVE_GETOPT_H)
 #include <getopt.h>
+#endif /* HAVE_GETOPT_H */
+#include "compat.h"
 
 #include "log_msg.h"
 
-#ifndef HAVE_STRDUP
-#include <compat/strdup.c>
-#endif
-
-#ifndef HAVE_GETOPT_LONG
-#include <compat/getopt.c>
-#include <compat/getopt1.c>
-#endif
-
-#ifndef HAVE_STRERROR
-#include <compat/strerror.c>
-#endif
-
 #ifndef YPMAPDIR
 #define YPMAPDIR "/var/yp"
 #endif
@@ -83,38 +74,6 @@ static u_int MapOrderNum;
 static u_int maxchildren = 1;
 static u_int children = 0;
 
-#if HAVE__RPC_DTABLESIZE
-extern int _rpc_dtablesize (void);
-#elif HAVE_GETDTABLESIZE
-
-int
-_rpc_dtablesize ()
-{
-  static int size;
-
-  if (size == 0)
-    size = getdtablesize ();
-
-  return size;
-}
-#else
-
-#include <sys/resource.h>
-
-int
-_rpc_dtablesize ()
-{
-  static int size = 0;
-  struct rlimit rlb;
-
-
-  if (size == 0)
-    if (getrlimit (RLIMIT_NOFILE, &rlb) >= 0)
-      size = rlb.rlim_cur;
-
-  return size;
-}
-#endif
 
 static char *
 yppush_err_string (enum yppush_status status)
@@ -158,9 +117,9 @@ yppush_err_string (enum yppush_status status)
 }
 
 bool_t
-yppushproc_null_1_svc (void *req __attribute__ ((unused)),
-		       void *resp __attribute__ ((unused)),
-		       struct svc_req *rqstp __attribute__ ((unused)))
+yppushproc_null_1_svc (void *req UNUSED,
+		       void *resp UNUSED,
+		       struct svc_req *rqstp UNUSED)
 {
   resp = NULL;
 
@@ -206,8 +165,6 @@ yppush_xfrrespprog_1(struct svc_req *rqstp, register SVCXPRT *transp)
   union {
     yppushresp_xfr yppushproc_xfrresp_1_arg;
   } argument;
-  union {
-  } result;
   bool_t retval;
   xdrproc_t _xdr_argument, _xdr_result;
   bool_t (*local)(char *, void *, struct svc_req *);
@@ -238,8 +195,8 @@ yppush_xfrrespprog_1(struct svc_req *rqstp, register SVCXPRT *transp)
       svcerr_decode (transp);
       return;
     }
-  retval = (bool_t) (*local)((char *)&argument, (void *)&result, rqstp);
-  if (retval > 0 && !svc_sendreply(transp, _xdr_result, (char *)&result))
+  retval = (bool_t) (*local)((char *)&argument, NULL, rqstp);
+  if (retval > 0 && !svc_sendreply(transp, _xdr_result, NULL))
     {
       svcerr_systemerr (transp);
     }
@@ -386,11 +343,11 @@ getordernum (void)
 #if defined(__NetBSD__)
 static int
 add_slave_server (u_long status, char *key, int keylen,
-		  char *val, int vallen, void *data __attribute__ ((unused)))
+		  char *val, int vallen, void *data UNUSED)
 #else
 static int
 add_slave_server (int status, char *key, int keylen,
-		  char *val, int vallen, char *data __attribute__ ((unused)))
+		  char *val, int vallen, char *data UNUSED)
 #endif
 {
   char host[YPMAXPEER + 2];
@@ -436,7 +393,7 @@ add_slave_server (int status, char *key, int keylen,
 }
 
 static void
-child_sig_int (int sig __attribute__ ((unused)))
+child_sig_int (int sig UNUSED)
 {
   if (CallbackProg != 0)
     svc_unregister (CallbackProg, 1);
@@ -478,8 +435,7 @@ yppush_foreach (const char *host)
   PushClient = clnt_create (server, YPPROG, YPVERS, "udp");
   if (PushClient == NULL)
     {
-      log_msg ("%s", host);
-      clnt_pcreateerror ("");
+      clnt_pcreateerror (server);
       return 1;
     }
 
@@ -555,7 +511,7 @@ yppush_foreach (const char *host)
 }
 
 static void
-sig_child (int sig __attribute__ ((unused)))
+sig_child (int sig UNUSED)
 {
   int status;
 
